@@ -1,10 +1,7 @@
 from collections import OrderedDict
-from pprint import pprint
 
 from rest_framework.pagination import PageNumberPagination
 from rest_framework.response import Response
-from rest_framework.views import exception_handler
-
 
 
 class CustomPagination(PageNumberPagination):
